@@ -458,7 +458,7 @@ class HarosSettings(object):
         self.cpp_compile_db = cpp_compile_db
         if cpp_compile_db is None:
             db = os.path.join(self.workspace, "build")
-            if os.path.isfile(db):
+            if os.path.isfile(os.path.join(db, "compile_commands.json")):
                 self.cpp_compile_db = db
         elif cpp_compile_db is False:
             self.cpp_compile_db = None
@@ -466,7 +466,7 @@ class HarosSettings(object):
     @classmethod
     def parse_from(cls, path):
         with open(path, "r") as handle:
-            data = yaml.load(handle)
+            data = yaml.load(handle) or {}
         env = data.get("environment")
         if env == "copy" or env == "all" or env is True:
             env = dict(os.environ)
