@@ -139,7 +139,7 @@ class HarosLauncher(object):
         try:
             if not os.path.isdir(self.HAROS_DIR):
                 print "[HAROS] It seems this is a first run."
-                self.command_init(args)
+                self.command_init(args, HarosSettings())
             try:
                 settings = HarosSettings.parse_from(self.USER_SETINGS)
             except IOError:
@@ -236,8 +236,8 @@ class HarosLauncher(object):
                             help = "use a copy of current environment")
         parser.add_argument("-d", "--data-dir",
                             help = "load/export using the given directory")
-        parser.add_argument("--cache-parsing", action = "store_true",
-                            help = "undocumented feature")
+        parser.add_argument("--no-cache", action = "store_true",
+                            help = "do not use available caches")
         group = parser.add_mutually_exclusive_group()
         group.add_argument("-w", "--whitelist", nargs = "*",
                            help = "execute only these plugins")
